#ifndef CAMERA_H
#define CAMERA_H

//    This file is part of Motion Watch.

//    Motion Watch is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    Motion Watch is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "common.h"

class Camera : public QObject
{
    Q_OBJECT

private:

    shared_t shared;

public:

    explicit Camera(QObject *parent = nullptr);

    int start(const QStringList &args);
};

class Loop : public QObject
{
    Q_OBJECT

protected:

    shared_t *shared;
    QTimer   *loopTimer;
    int       heartBeat;

protected slots:

    virtual void init();

private slots:

    void loopSlot();

public:

    explicit Loop(shared_t *shared, QThread *thr, QObject *parent = nullptr);

    virtual bool exec();
};

class Upkeep : public Loop
{
    Q_OBJECT

public:

    explicit Upkeep(shared_t *shared, QThread *thr, QObject *parent = nullptr);

    bool exec();
};

class EventLoop : public Loop
{
    Q_OBJECT

private:

    QStringList vidList;
    QString     imgPath;
    QString     name;
    float       highScore;
    uint        cycles;

    bool wrOutVod();

public:

    explicit EventLoop(shared_t *shared, QThread *thr, QObject *parent = nullptr);

    bool exec();
};

class DetectLoop : public Loop
{
    Q_OBJECT

private:

    QTimer *pcTimer;
    uint    delayCycles;
    bool    mod;
    quint64 seed;

    void        resetTimers();
    float       getFloatFromExe(const QByteArray &line);
    QStringList buildArgs(const QString &prev, const QString &next);
    QStringList buildSnapArgs(const QString &vidSrc, const QString &imgPath);

private slots:

    void init();
    void pcBreak();

public:

    explicit DetectLoop(shared_t *shared, QThread *thr, QObject *parent = nullptr);

    bool exec();
};

#endif // CAMERA_H
