#ifndef COMMON_H
#define COMMON_H

//    This file is part of Motion Watch.

//    Motion Watch is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    Motion Watch is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include <QCoreApplication>
#include <QProcess>
#include <QTextStream>
#include <QObject>
#include <QDir>
#include <QFile>
#include <QDateTime>
#include <QThread>
#include <QTimer>
#include <QStringList>
#include <QMutex>
#include <QRegularExpression>
#include <iostream>

using namespace std;

#define APP_VER      "3.3.t3"
#define APP_NAME     "Motion Watch"
#define APP_BIN      "mow"
#define REC_LOG_NAME "rec.log"
#define DET_LOG_NAME "det.log"
#define UPK_LOG_NAME "upk.log"
#define DATETIME_FMT "yyyyMMddhhmmss"
#define STRFTIME_FMT "%Y%m%d%H%M%S"
#define MAX_IMAGES   1000
#define MAX_VIDEOS   1000
#define PREV_IMG     "&prev&"
#define NEXT_IMG     "&next&"

enum CmdExeType
{
    MAIN_LOOP,
    VID_LOOP,
    IMG_LOOP
};

struct evt_t
{
    QDateTime timeStamp;
    QString   imgPath;
    float     score;
    uint      queAge;
};

struct shared_t
{
    QList<evt_t> recList;
    QMutex       recMutex;
    QMutex       logMutex;
    QString      conf;
    QString      recLog;
    QString      detLog;
    QString      recordUri;
    QString      buffPath;
    QString      postCmd;
    QString      camName;
    QString      recPath;
    QString      outputType;
    QString      compCmd;
    QString      streamCodec;
    QString      streamExt;
    QString      recExt;
    QString      thumbExt;
    QString      recScale;
    QString      imgScale;
    QString      servMainLoop;
    QString      servVidLoop;
    QString      servImgLoop;
    QString      servUser;
    bool         singleTenant;
    bool         skipCmd;
    int          recFps;
    int          imgThreads;
    int          recThreads;
    int          evMaxSecs;
    int          postSecs;
    int          imgThresh;
    int          maxEvents;
    int          maxLogSize;
    int          retCode;
};

QString     getParam(const QString &key, const QStringList &args);
QString     buildThreadCount(int count);
QStringList lsFilesInDir(const QString &path, const QString &ext = QString());
QStringList lsDirsInDir(const QString &path);
QStringList listFacingFiles(const QString &path, const QString &ext, const QDateTime &stamp, int secs, char dir);
QStringList backwardFacingFiles(const QString &path, const QString &ext, const QDateTime &stamp, int secs);
QStringList forwardFacingFiles(const QString &path, const QString &ext, const QDateTime &stamp, int secs);
QStringList parseArgs(const QByteArray &data, int maxArgs, int *pos = nullptr);
bool        rdConf(const QString &filePath, shared_t *share);
bool        mkPath(const QString &path);
void        rdLine(const QString &param, const QString &line, QString *value);
void        rdLine(const QString &param, const QString &line, int *value);
void        rdLine(const QString &param, const QString &line, bool *value);
void        enforceMaxEvents(shared_t *share);
void        enforceMaxImages(shared_t *share);
void        enforceMaxVids(shared_t *share);
void        extCorrection(QString &ext);

#endif // COMMON_H
